@@ -110,19 +110,3 @@ B <-matrix(c(0,0,-0.8,-0.7,1,-0.2,0.8,0.7,0,0,-0.2,1),nrow=6,ncol=2)
 Align.Matrix(Order.Matrix=A, Input.Matrix=B)
 
 
-## -----------------------------------------------------------------------------
-#Examples using the data sets included in the packages:
-  
-data("BFI228")    # Big-five inventory (N = 228)
-
-#For ordinal data, estimating the polychoric correlation and its ACM 
-#with 5 cores and 1/(nc*nr) added to all cells
-
-polyACM = PolychoricRM(BFI228,NCore=5, IAdjust=1, estimate.acm=T)
-
-polyACM$threshold
-polyACM$correlation
-polyACM$flag
-polyACM$ACM
-
-
